@@ -121,31 +121,31 @@ class DBManager(object):
     def close(self):
         self.engine.dispose()
 
-    def align_keys_by_table(self, table, keys):
+    def align_keys_by_table(self, table, data):
         '''
         依照数据表的定义来对齐字段。
         多余的字段丢掉
         '''
+        if type(data) == dict:
+            data = [data]
+        data_keys = list(data[0].keys())
         database = self.engine.url.database
         sql = f'select COLUMN_NAME from information_schema.COLUMNS where TABLE_SCHEMA="{database}" and TABLE_NAME="{table}"'
-        result = self.execute(sql)
-        if result:
-            result = [r[0] for r in result]
-        arr = []
-        for key in keys:
-            if key in result:
-                arr.append(key)
-        return arr
+        table_keys = self.execute(sql)
+        if table_keys:
+            table_keys = [r[0] for r in table_keys]
+        for data_key in data_keys:
+            if data_key not in table_keys:
+                for it in data:
+                    if it.get(data_key) is not None:
+                        del it[data_key]
+        return table_keys
 
     def align_data_keys(self, data, table):
         if not data:
             return False
-        if type(data) == list:
-            keys = list(data[0].keys())
-        else:
-            keys = list(data.keys())
-        keys = self.align_keys_by_table(table, keys)
-        fill_empty_fields(keys, data)
+        table_keys = self.align_keys_by_table(table, data)
+        fill_empty_fields(table_keys, data)
         return True
 
 
